# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/apache-xmlsec/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free

Name:           xml-security
Version:        1.4.3
Release:        6%{?dist}
Epoch:          0
Summary:        Implementation of W3C security standards for XML
License:        ASL 2.0
URL:            http://santuario.apache.org/
Group:          Text Processing/Markup/XML
Source0:        http://santuario.apache.org/dist/java-library/xml-security-src-1_4_3.zip
Source1:        xml-security-component-info.xml
Source2:        xmlsec-1.4.3.pom
Patch0:         xml-security-build_xml.patch
Patch1:         xml-security-disable-test-fail.patch

#Requires:      bouncycastle
Requires:       jakarta-commons-logging
Requires:       log4j
Requires:       xalan-j2 >= 0:2.7
Requires:       xml-commons-jaxp-1.3-apis >= 0:1.3
Requires:       xerces-j2 >= 0:2.7
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  ant-nodeps
BuildRequires:  ant-trax
BuildRequires:  java-devel >= 0:1.5
#BuildRequires: bouncycastle
BuildRequires:  jakarta-commons-logging
BuildRequires:  log4j
BuildRequires:  xalan-j2 >= 0:2.7
BuildRequires:  xml-commons-jaxp-1.3-apis
BuildRequires:  xerces-j2 >= 0:2.7
# To create content for maven2-brew
BuildRequires:  maven-deploy-plugin

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The XML Security project is aimed at providing implementation 
of security standards for XML. Currently the focus is on the 
W3C standards :
- XML-Signature Syntax and Processing; and
- XML Encryption Syntax and Processing.
Once these are implemented, XML Key Management is likely to 
be the next focus for the project.
Two libraries are currently available.
A Java library, which includes a mature Digital Signature 
implementation. Encryption is currently under development.
A C++ library is also now available. Functionality is 
currently more basic than that provided by the Java library.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%package demo
Summary:        Samples for %{name}
Group:          Development/Documentation

%description demo
Samples for %{name}.

%prep
%setup -q -n xml-security-1_4_3
%patch0 -p0
%patch1 -p0

mkdir -p libs/endorsed
pushd libs
ln -s $(build-classpath commons-logging)
ln -s $(build-classpath commons-logging-api)
ln -s $(build-classpath junit)
ln -s $(build-classpath log4j)
ln -s $(build-classpath xalan-j2)
ln -s $(build-classpath xalan-j2-serializer)
ln -s $(build-classpath xerces-j2)
ln -s $(build-classpath xml-commons-jaxp-1.3-apis)
popd

%build
export CLASSPATH=
export OPT_JAR_LIST="junit ant/ant-junit jaxp_transform_impl ant/ant-trax xalan-j2-serializer"
%{ant} -Djava.endorsed.dirs=libs -Dlib.xalan.3=libs/xml-commons-jaxp-1.3-apis.jar build.src build.jar build.docs
# FIXME: (dwalluck) AES key size above 128 will fail with default Sun JCE provider policy
%{ant} -Djava.endorsed.dirs=libs -Dlib.xalan.3=libs/xml-commons-jaxp-1.3-apis.jar test

%install
%{__rm} -rf %{buildroot}

install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 644 build/xmlsec-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
ln -s %{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/xmlsec-%{version}.jar
install -p -m 644 build/xmlsecSamples-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-samples-%{version}.jar
ln -s %{name}-samples-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/xmlsecSamples-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} ${jar/-%{version}/}; done)

install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/docs/html/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}
cp -pr src_samples/* $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_datadir}/%{name}

# poms
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
%add_to_maven_depmap org.apache.santuario xmlsec %{version} JPP %{name}
%add_to_maven_depmap org.apache xmlsec %{version} JPP %{name}
%add_to_maven_depmap xml-security xmlsec %{version} JPP %{name}
install -p -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom

%if %with repolib
install -d -m 755 $RPM_BUILD_ROOT%{repodir}
%{_bindir}/mvn-jpp deploy:deploy-file \
	-DgroupId=org.apache \
	-DartifactId=xmlsec \
	-Dversion=%{version} \
	-Dpackaging=jar \
	-Dfile=%{buildroot}%{_javadir}/%{name}-%{version}.jar \
	-DpomFile=%{SOURCE2} \
	-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
	-DrepositoryId=jboss-releases
install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
install -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
sed -i "s/@VERSION@/%{version}-brew/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
cp -p $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar $RPM_BUILD_ROOT%{repodirlib}/xmlsec.jar
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{repodirlib}/xmlsec.pom
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc LICENSE
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/xmlsec-%{version}.jar
%{_javadir}*/xmlsec.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files demo
%defattr(0644,root,root,0755)
%{_javadir}*/%{name}-samples-%{version}.jar
%{_javadir}*/%{name}-samples.jar
%{_javadir}*/xmlsecSamples-%{version}.jar
%{_javadir}*/xmlsecSamples.jar
%{_datadir}/%{name}-%{version}
%{_datadir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Fri Jan 14 2011 Hui Wang <huwang@redhat.com> - 0:1.4.3-6
- Rebuild
- Use deploy command instead of upload.sh

* Tue Nov 23 2010 Hui Wang <huwang@redhat.com> - 0:1.4.3-5
- Add upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars

* Mon May 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.4.3-4.1
- rebuilt

* Mon Apr 19 2010 Yiqiao Wang <yiwang@redhat.com> 0:1.4.3-4
- Rebuild

* Wed Nov 18 2009 Permaine Cheung <pcheung@redhat.com> 0:1.4.3-3
- Add pom and maven fragments

* Fri Aug 14 2009 Permaine Cheung <pcheung@redhat.com> 0:1.4.3-2
- Fix repodir

* Fri Aug 14 2009 Permaine Cheung <pcheung@redhat.com> 0:1.4.3-1
- Upgrade to 1.4.3

* Tue May 26 2009 David Walluck <dwalluck@redhat.com> 0:1.4.2-2
- fix log4j location in patch

* Tue May 26 2009 David Walluck <dwalluck@redhat.com> 0:1.4.2-1
- 1.4.2

* Mon Jan 12 2009 David Walluck <dwalluck@redhat.com> 0:1.3.0-3
- add compiled samples jar to demo subpackage
- specify xml-commons-jaxp-1.3-apis explicitly
- rename repolib directory for AS5
- fix repolib permissions
- fix repolib file ownership

* Wed May 28 2008 David Walluck <dwalluck@redhat.com> 0:1.3.0-2.jpp5
- don't remove buildroot in %%prep
- don't use absolute path for %%doc
- fix License

* Mon Apr 21 2008 David Walluck <dwalluck@redhat.com> 0:1.3.0-1jpp.ep1.3
- unpatched version requires ant-nodeps
- fix tests
- remove javadoc scriptlets
- remove %%{buildroot} in %%install
- rename BuildRoot

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.0-1jpp.ep1.2
- Fix repolib location

* Tue Mar 13 2007 Fernando nasser <fnasser@redhat.com> 0:1.3.0-1jpp.ep1.1
- Remove duplicate macros

* Tue Feb 20 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.0-1jpp.el4ep1.2
- Install jar with name as used upstream
- Add -brew suffix

* Sun Feb 18 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.3.0-1jpp.el4ep1.1
- Add repolib support
- Add missing BR on ant-junit

* Tue Aug 01 2006 Fernando nasser <fnasser@redhat.com> 0:1.3.0-1jpp_1rh
- Merge with upstream

* Tue Jan 17 2006 Deepak Bhole <dbhole@redhat.com> 0:1.3.0-1jpp
- Upgrade to version 1.3.0.
- Removed com.sun dependencies.
- Removed bouncycastle dependency.

* Thu Oct 20 2005 Fernando nasser <fnasser@redhat.com> 0:1.2.1-1jpp_1rh
- First Red Hat build
- Remove bouncycastle
- Lower Xalan-j2 requires to 2.6.0

* Mon Oct 10 2005 Ralph Apel <r.apel at r-apel.de> 0:1.2.97-1jpp
- Upgrade to build/run with JAXP-1.3

* Mon Apr 04 2005 Ralph Apel <r.apel at r-apel.de> 0:1.2.1-1jpp
- First JPackage release
